@@ -1,14 +1,17 @@
 import torch
 
+from .nn import NN
 from .. import activations
 from .. import initializers
 
 
-class FNN(torch.nn.Module):
+class FNN(NN):
     """Fully-connected neural network."""
 
     def __init__(self, layer_sizes, activation, kernel_initializer):
         super(FNN, self).__init__()
+        self.inputs = None
+
         self.activation = activations.get(activation)
         initializer = initializers.get(kernel_initializer)
         initializer_zero = initializers.get("zeros")
@@ -19,8 +22,13 @@ class FNN(torch.nn.Module):
             initializer(self.linears[-1].weight)
             initializer_zero(self.linears[-1].bias)
 
-    def forward(self, x):
+    def forward(self, inputs):
+        x = inputs
+        if self._input_transform is not None:
+            x = self._input_transform(x)
         for linear in self.linears[:-1]:
             x = self.activation(linear(x))
         x = self.linears[-1](x)
+        if self._output_transform is not None:
+            x = self._output_transform(inputs, x)
         return x
